==> guikachu-0.3.tar.gz: guikachu-0.3/src/dialog-win.h <==
//$Id: dialog-win.h,v 1.6 2001/03/11 18:16:16 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKATCHU_DIALOG_WIN_H
#define GUIKATCHU_DIALOG_WIN_H

namespace Guikachu
{
    namespace GUI
    {
	class DialogWindow;
    }
}

#include "dialog-res.h"

#include <gtk--/window.h>
#include <gtk--/entry.h>
#include <gtk--/text.h>
#include <gtk--/optionmenu.h>
#include <gtk--/button.h>
#include <gtk--/list.h>
#include "resource-combo.h"

#include <glade/glade-xml.h>

namespace Guikachu
{
    namespace GUI
    {
	class DialogWindow: public SigC::Object
	{
	    Resources::Dialog   *res;
	    
	    GladeXML            *gui;
	    Gtk::Window         *window;
	    
	    Gtk::Entry          *id_entry;
	    Gtk::Entry          *title_entry;
	    Gtk::Text           *text_entry;
	    Gtk::OptionMenu     *type_combo;
	    GUI::ResourceCombo   help_combo;
	    
	    Gtk::List           *button_list;
	    Gtk::Button         *btnUp, *btnDown, *btnRemove, *btnAdd, *btnDefault;
	public:
	    DialogWindow (Resources::Dialog *res_);
	    ~DialogWindow ();
	    void show ();
	private:
	    int delete_event_impl (GdkEventAny *e);
	    void update ();

	    void id_entry_cb (GdkEventFocus *e);
	    void title_entry_cb (GdkEventFocus *e);
	    void text_entry_cb ();
	    void type_menu_cb (Resources::DialogType type);
	    void help_combo_cb (const string& help_id);
	    bool update_block;

	    void button_add_cb ();
	    void button_remove_cb ();
	    void button_default_cb ();
	    void button_up_cb ();
	    void button_down_cb ();
	    void button_sel_change_cb ();

	    void dialog_add_cb (string name);
	};
    };
};

#endif /* !GUIKATCHU_DIALOG_WIN_H */

==> guikachu-0.4.tar.gz: guikachu-0.4/src/dialog-win.h <==
//$Id: dialog-win.h,v 1.8 2001/04/14 18:01:39 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKATCHU_DIALOG_WIN_H
#define GUIKATCHU_DIALOG_WIN_H

namespace Guikachu
{
    namespace GUI
    {
	class DialogWindow;
    }
}

#include "dialog-res.h"

#include <gtk--/window.h>
#include <gtk--/entry.h>
#include <gtk--/text.h>
#include <gtk--/optionmenu.h>
#include <gtk--/button.h>
#include <gtk--/list.h>
#include "widgets/resource-combo.h"

#include <glade/glade-xml.h>

namespace Guikachu
{
    namespace GUI
    {
	class DialogWindow: public SigC::Object
	{
	    Resources::Dialog   *res;
	    
	    GladeXML            *gui;
	    Gtk::Window         *window;
	    
	    Gtk::Entry          *id_entry;
	    Gtk::Entry          *title_entry;
	    Gtk::Text           *text_entry;
	    Gtk::OptionMenu     *type_combo;
	    GUI::ResourceCombo   help_combo;
	    
	    Gtk::List           *button_list;
	    Gtk::Button         *btnUp, *btnDown, *btnRemove, *btnAdd, *btnDefault;
	public:
	    DialogWindow (Resources::Dialog *res_);
	    ~DialogWindow ();
	    void show ();
	private:
	    int delete_event_impl (GdkEventAny *e);
	    void update ();

	    void id_entry_cb ();
	    void title_entry_cb ();
	    void text_entry_cb ();
	    void type_menu_cb (Resources::DialogType type);
	    bool update_block;

	    void button_add_cb ();
	    void button_remove_cb ();
	    void button_default_cb ();
	    void button_up_cb ();
	    void button_down_cb ();
	    void button_sel_change_cb ();

	    void dialog_add_cb (string name);
	};
    };
};

#endif /* !GUIKATCHU_DIALOG_WIN_H */
